==> arm-compute-library_23.08+dfsg.orig.tar.xz: arm-compute-library-23.08+dfsg/src/common/utils/Object.h <==
/*
 * Copyright (c) 2021 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef SRC_COMMON_OBJECT_H_
#define SRC_COMMON_OBJECT_H_

#include <cstdint>

namespace arm_compute
{
// Forward declarations
class IContext;

namespace detail
{
/**< Object type enumerations */
enum class ObjectType : uint32_t
{
    Context    = 1,
    Queue      = 2,
    Tensor     = 3,
    TensorPack = 4,
    Operator   = 5,
    Invalid    = 0x56DEAD78
};

/**< API Header meta-data construct used by all opaque constructs */
struct Header
{
    /** Constructor
     *
     * @param[in] type_ Object identification type
     * @param[in] ctx_  Context to reference
     */
    Header(ObjectType type_, IContext *ctx_) noexcept
        : type(type_),
          ctx(ctx_)
    {
    }

    ObjectType type{ ObjectType::Invalid };
    IContext *ctx{ nullptr };
};
} // namespace detail
} // namespace arm_compute
#endif /* SRC_COMMON_OBJECT_H_ */

==> arm-compute-library_24.11+dfsg.orig.tar.xz: arm-compute-library-24.11+dfsg/src/common/utils/Object.h <==
/*
 * Copyright (c) 2021 Arm Limited.
 *
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef SRC_COMMON_OBJECT_H_
#define SRC_COMMON_OBJECT_H_

#include <cstdint>

namespace arm_compute
{
// Forward declarations
class IContext;

namespace detail
{
/**< Object type enumerations */
enum class ObjectType : uint32_t
{
    Context    = 1,
    Queue      = 2,
    Tensor     = 3,
    TensorPack = 4,
    Operator   = 5,
    Invalid    = 0x56DEAD78
};

/**< API Header meta-data construct used by all opaque constructs */
struct Header
{
    /** Constructor
     *
     * @param[in] type_ Object identification type
     * @param[in] ctx_  Context to reference
     */
    Header(ObjectType type_, IContext *ctx_) noexcept : type(type_), ctx(ctx_)
    {
    }

    ObjectType type{ObjectType::Invalid};
    IContext  *ctx{nullptr};
};
} // namespace detail
} // namespace arm_compute
#endif /* SRC_COMMON_OBJECT_H_ */
